"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decodeGedcom = void 0;
const gedcom_1 = require("gedcom");
const simple_family_tree_model_1 = require("simple-family-tree-model");
function decodeGedcom(fTree, gedcomData) {
    let localGedcomData = gedcomData;
    let firstProfile = false;
    //console.log("data length ", gedcomData.length);
    //console.log("data ", gedcomData);
    const familyTree = (0, gedcom_1.parse)(localGedcomData);
    //console.log(familyTree)
    (0, gedcom_1.compact)(familyTree);
    //console.log(familyTree)
    // First pass, add profiles to tree
    for (let i = 0; i < familyTree.children.length; i++) {
        if (familyTree.children[i].type === "INDI") {
            let gedcomIndividual = familyTree.children[i];
            //console.log(gedcomIndividual);
            if (gedcomIndividual.data !== undefined) {
                const personData = gedcomIndividual.data;
                //console.log(personData);
                //console.log(personData.SEX);
                //console.log(personData.xref_id);
                const name = String(personData.NAME).replaceAll('/', '');
                let sex = simple_family_tree_model_1.ProfileSex.Unknown;
                if (personData.SEX === "F") {
                    sex = simple_family_tree_model_1.ProfileSex.Female;
                }
                else if (personData.SEX === "M") {
                    sex = simple_family_tree_model_1.ProfileSex.Male;
                }
                //console.log(name);
                let birthDate = "";
                if (personData["BIRTH/DATE"] !== undefined) {
                    birthDate = String(personData["BIRTH/DATE"]);
                }
                let birthPlace = "";
                if (personData["BIRTH/PLACE"] !== undefined) {
                    birthPlace = String(personData["BIRTH/PLACE"]);
                }
                let deathDate = "";
                if (personData["DEATH/DATE"] !== undefined) {
                    deathDate = String(personData["DEATH/DATE"]);
                }
                let deathPlace = "";
                if (personData["DEATH/PLACE"] !== undefined) {
                    deathPlace = String(personData["DEATH/PLACE"]);
                }
                //creatAndAddPerson(personData.NAME, personData.)
                let profile = (0, simple_family_tree_model_1.createProfile)(name, sex, birthDate, birthPlace, deathDate, deathPlace);
                profile.profileId = new simple_family_tree_model_1.ProfileLink(String(personData.xref_id));
                let result = fTree.addNewProfile(profile);
                //console.log("added profile ", result);
                if (firstProfile) {
                    firstProfile = false;
                    console.log("focusperson {}", result);
                }
            }
        }
    }
    // Second pass, add family connections to tree
    for (let i = 0; i < familyTree.children.length; i++) {
        if (familyTree.children[i].type === "FAM") {
            let gedcomFamily = familyTree.children[i];
            //console.log(gedcomFamily);
            if (gedcomFamily.data !== undefined) {
                const familyData = gedcomFamily.data;
                //console.log(familyData);
                //console.log(personData.SEX);
                //console.log(personData.xref_id);
                let familyId = String(familyData["xref_id"]);
                let family = new simple_family_tree_model_1.Family();
                family.familyId = new simple_family_tree_model_1.FamilyLink(familyId);
                fTree.addNewFamily(family);
                if (familyData["@HUSBAND"] !== undefined) {
                    let result = fTree.addParentToFamily(new simple_family_tree_model_1.FamilyLink(familyId), new simple_family_tree_model_1.ProfileLink(String(familyData["@HUSBAND"])));
                    //console.log("husband in fam", result);
                    //family.parents.append(new ProfileLink(String(familyData["@HUSBAND"])));
                }
                if (familyData["@WIFE"] !== undefined) {
                    let result = fTree.addParentToFamily(new simple_family_tree_model_1.FamilyLink(familyId), new simple_family_tree_model_1.ProfileLink(String(familyData["@WIFE"])));
                    //console.log("wife in fam", result);
                    //family.parents.append(new ProfileLink(String(familyData["@WIFE"])));
                }
                if (familyData["@CHILD"] !== undefined) {
                    let result = fTree.addChildToFamily(new simple_family_tree_model_1.FamilyLink(familyId), new simple_family_tree_model_1.ProfileLink(String(familyData["@CHILD"])));
                    //console.log("child in fam", result);
                    //family.children.append(new ProfileLink(String(familyData["@CHILD"])));
                }
            }
        }
    }
}
exports.decodeGedcom = decodeGedcom;
